using System;
using Cpp2IlInjected;
using DG.Tweening;
using DG.Tweening.Core;
using DG.Tweening.Plugins.Options;
using MarsSDK;
using UnityEngine;
using UnityEngine.UI;

// Token: 0x0200025C RID: 604
[Token(Token = "0x200025C")]
[RequireComponent(typeof(RectTransform), typeof(CanvasGroup))]
public class UIGameSavePage : MonoBehaviour
{
	// Token: 0x06001743 RID: 5955 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001743")]
	[Address(RVA = "0x763560", Offset = "0x762360", VA = "0x180763560")]
	public void Init(int pageIndex, UIHandlerBase backHandler)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001744 RID: 5956 RVA: 0x00038970 File Offset: 0x00036B70
	[Token(Token = "0x6001744")]
	[Address(RVA = "0x763D30", Offset = "0x762B30", VA = "0x180763D30")]
	public void SetupNavigation(UINavigator navigator)
	{
		UIGameSaveHandler[] array = this.saveDataHandlers;
		navigator.BindPointerEnterEvent(array);
		UIGameSaveHandler[] array2 = this.saveDataHandlers;
		navigator.BindPointerExitEvent(array2);
		UIGameSaveDeleteHandler[] array3 = this.deleteHandlers;
		navigator.BindPointerEnterEvent(array3);
		UIGameSaveDeleteHandler[] array4 = this.deleteHandlers;
		navigator.BindPointerExitEvent(array4);
	}

	// Token: 0x06001745 RID: 5957 RVA: 0x000389BC File Offset: 0x00036BBC
	[Token(Token = "0x6001745")]
	[Address(RVA = "0x763350", Offset = "0x762150", VA = "0x180763350")]
	public void BindSaveDataSelectionEvents(Action<UIHandlerBase> onSelected, Action<UIHandlerBase> onDeselected)
	{
		UIGameSaveHandler[] array = this.saveDataHandlers;
		int num = 0;
		int length = array.Length;
		if (num < length)
		{
			UIGameSaveHandler uigameSaveHandler = array[num];
			uigameSaveHandler.onSelectedHandler = onSelected;
			uigameSaveHandler.onDeselectedHandler = onDeselected;
			num++;
		}
	}

	// Token: 0x06001746 RID: 5958 RVA: 0x00038A00 File Offset: 0x00036C00
	[Token(Token = "0x6001746")]
	[Address(RVA = "0x7632B0", Offset = "0x7620B0", VA = "0x1807632B0")]
	public void BindDeleteSelectionEvents(Action<UIHandlerBase> onSelected, Action<UIHandlerBase> onDeselected)
	{
		UIGameSaveDeleteHandler[] array = this.deleteHandlers;
		int num = 0;
		int length = array.Length;
		if (num < length)
		{
			UIGameSaveDeleteHandler uigameSaveDeleteHandler = array[num];
			uigameSaveDeleteHandler.onSelectedHandler = onSelected;
			uigameSaveDeleteHandler.onDeselectedHandler = onDeselected;
			num++;
		}
	}

	// Token: 0x06001747 RID: 5959 RVA: 0x00038A44 File Offset: 0x00036C44
	[Token(Token = "0x6001747")]
	[Address(RVA = "0x763BF0", Offset = "0x7629F0", VA = "0x180763BF0")]
	public void SetActive(UINavigator navigator, int selectedHandlerIndex, UIHandlerBase backHandler)
	{
		this.SetActive(navigator, backHandler);
		UIGameSaveHandler uigameSaveHandler = this.saveDataHandlers[selectedHandlerIndex];
		navigator.SetDefaultHandler(uigameSaveHandler);
		UIGameSaveDeleteHandler uigameSaveDeleteHandler = this.deleteHandlers[selectedHandlerIndex];
		this.lastDeleteHandler = uigameSaveDeleteHandler;
		throw new NullReferenceException();
	}

	// Token: 0x06001748 RID: 5960 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001748")]
	[Address(RVA = "0x763A80", Offset = "0x762880", VA = "0x180763A80")]
	public void SetActive(UINavigator navigator, UIHandlerBase backHandler)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001749 RID: 5961 RVA: 0x00038A88 File Offset: 0x00036C88
	[Token(Token = "0x6001749")]
	[Address(RVA = "0x763CA0", Offset = "0x762AA0", VA = "0x180763CA0")]
	public void SetInactive()
	{
		CanvasGroup canvasGroup = this.canvasGroup;
		int num = 0;
		canvasGroup.blocksRaycasts = num != 0;
		UIGameSaveDeleteHandler[] array = this.deleteHandlers;
		int num2 = 0;
		int length = array.Length;
		if (num2 < length)
		{
			Image icon = array[num2].icon;
			int num3 = 0;
			icon.enabled = num3 != 0;
			num2++;
		}
	}

	// Token: 0x0600174A RID: 5962 RVA: 0x00038AE0 File Offset: 0x00036CE0
	[Token(Token = "0x600174A")]
	[Address(RVA = "0x763FA0", Offset = "0x762DA0", VA = "0x180763FA0")]
	public void UpdateRaycastTarget(bool enable)
	{
		this.canvasGroup.blocksRaycasts = enable;
	}

	// Token: 0x0600174B RID: 5963 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x600174B")]
	[Address(RVA = "0x7633F0", Offset = "0x7621F0", VA = "0x1807633F0")]
	public Tween GetPageFadeInTween(float duration)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x0600174C RID: 5964 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x600174C")]
	[Address(RVA = "0x763410", Offset = "0x762210", VA = "0x180763410")]
	public Tween GetPageFadeOutTween(float duration)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x0600174D RID: 5965 RVA: 0x00038B00 File Offset: 0x00036D00
	[Token(Token = "0x600174D")]
	[Address(RVA = "0x763F80", Offset = "0x762D80", VA = "0x180763F80")]
	public void UpdatePageAlpha(float alpha)
	{
		this.canvasGroup.alpha = alpha;
	}

	// Token: 0x0600174E RID: 5966 RVA: 0x00038B20 File Offset: 0x00036D20
	[Token(Token = "0x600174E")]
	[Address(RVA = "0x763110", Offset = "0x761F10", VA = "0x180763110")]
	public void AppearDeleteHandler(int index)
	{
		if (this.lastDeleteHandler)
		{
			Image icon = this.lastDeleteHandler.icon;
			int num = 0;
			TweenerCore<Color, Color, ColorOptions> tweenerCore = DOTweenModuleUI.DOFade(icon, (float)num, 0.3f).SetEase((Ease)((uint)15)).Play<TweenerCore<Color, Color, ColorOptions>>();
		}
		UIGameSaveDeleteHandler uigameSaveDeleteHandler = this.deleteHandlers[index];
		this.lastDeleteHandler = uigameSaveDeleteHandler;
		TweenerCore<Color, Color, ColorOptions> tweenerCore2 = DOTweenModuleUI.DOFade(this.lastDeleteHandler.icon, 1f, 0.3f).SetEase((Ease)((uint)15)).Play<TweenerCore<Color, Color, ColorOptions>>();
	}

	// Token: 0x0600174F RID: 5967 RVA: 0x00038BA8 File Offset: 0x00036DA8
	[Token(Token = "0x600174F")]
	[Address(RVA = "0x763470", Offset = "0x762270", VA = "0x180763470")]
	public void HideDeleteHandler()
	{
		if (this.lastDeleteHandler)
		{
			Image icon = this.lastDeleteHandler.icon;
			int num = 0;
			TweenerCore<Color, Color, ColorOptions> tweenerCore = DOTweenModuleUI.DOFade(icon, (float)num, 0.3f).SetEase((Ease)((uint)15)).Play<TweenerCore<Color, Color, ColorOptions>>();
			this.lastDeleteHandler = (ulong)0L;
		}
	}

	// Token: 0x06001750 RID: 5968 RVA: 0x00038BFC File Offset: 0x00036DFC
	[Token(Token = "0x6001750")]
	[Address(RVA = "0x7639F0", Offset = "0x7627F0", VA = "0x1807639F0")]
	private void ProcessHandlerAlpha(UIGameSaveDeleteHandler handler, float alpha)
	{
		TweenerCore<Color, Color, ColorOptions> tweenerCore = DOTweenModuleUI.DOFade(handler.icon, alpha, 0.3f).SetEase((Ease)((uint)15)).Play<TweenerCore<Color, Color, ColorOptions>>();
	}

	// Token: 0x06001751 RID: 5969 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001751")]
	[Address(RVA = "0x763DA0", Offset = "0x762BA0", VA = "0x180763DA0")]
	public void UpdateContent(LocalizationData data)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001752 RID: 5970 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001752")]
	[Address(RVA = "0x7638D0", Offset = "0x7626D0", VA = "0x1807638D0")]
	public void Localize(LocalizationData data)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001753 RID: 5971 RVA: 0x00038C30 File Offset: 0x00036E30
	[Token(Token = "0x6001753")]
	[Address(RVA = "0x3088F0", Offset = "0x3076F0", VA = "0x1803088F0")]
	public UIGameSavePage()
	{
	}

	// Token: 0x04002193 RID: 8595
	[FieldOffset(Offset = "0x18")]
	[Token(Token = "0x4002193")]
	[SerializeField]
	private int pageIndex;

	// Token: 0x04002194 RID: 8596
	[FieldOffset(Offset = "0x20")]
	[Token(Token = "0x4002194")]
	[SerializeField]
	private CanvasGroup canvasGroup;

	// Token: 0x04002195 RID: 8597
	[FieldOffset(Offset = "0x28")]
	[Token(Token = "0x4002195")]
	[SerializeField]
	private UIGameSaveHandler[] saveDataHandlers;

	// Token: 0x04002196 RID: 8598
	[FieldOffset(Offset = "0x30")]
	[Token(Token = "0x4002196")]
	[SerializeField]
	private UIGameSaveDeleteHandler[] deleteHandlers;

	// Token: 0x04002197 RID: 8599
	[FieldOffset(Offset = "0x38")]
	[Token(Token = "0x4002197")]
	private UIGameSaveDeleteHandler lastDeleteHandler;
}
